==> mysocials_0.2-1.1.tar.gz: mysocials-0.2/src/db/db_general.h <==
/*
 * db_general.h - header file described some usefull text constant 
 * and enumerations using in DB subsystem of MSA
 *
 * This file is part of MSA program
 *
 * Copyright (C) 2009 - Alexander A. Lomov
 *
 * MSA program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MSA program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MSA program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */
 
 // $id$

#ifndef __DB_GENERAL_H__
#define __DB_GENERAL_H__


#ifndef DATADIR
#define DATADIR "./"
#endif

#define XML_VERSION "1.0"
#define XML_CODING "UTF-8"

#define HOME_DIR g_get_home_dir()
#define CONFIG_FILE_NAME "db_config.rc"

#define PROGRAM_DIR_NAME ".msa/"
#define CONFIG_FILE_PATH DATADIR"/"CONFIG_FILE_NAME
#define CONFIG_FILE_PATH_HOME HOME_DIR"/"PROGRAM_DIR_NAME"/"CONFIG_FILE_NAME
#define HOME_PATH "./"
#define HOME_PROGRAM_PATH "./"
#define HOME_PROGRAM_DB_PATH "./"

//#define TABLE_PROFILES "profiles"
//#define TABLE_GROUPS "profiles"


#endif /* __DB_GENERAL_H__ */

==> mysocials_0.2-1.12.tar.gz: mysocials-0.2/src/db/db_general.h <==
/*
 * db_general.h - header file described some usefull text constant 
 * and enumerations using in DB subsystem of MSA
 *
 * This file is part of MSA program
 *
 * Copyright (C) 2009 - Alexander A. Lomov
 *
 * MSA program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MSA program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MSA program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */
 
 // $id$

#ifndef __DB_GENERAL_H__
#define __DB_GENERAL_H__


//#ifndef DATADIR
//#define DATADIR "./"
//#endif

#define XML_VERSION "1.0"
#define XML_CODING "UTF-8"

#define HOME_DIR g_get_home_dir()
#define CONFIG_FILE_NAME "db_config.rc"

//#define PROGRAM_DIR_NAME ".msa/"
//#define CONFIG_FILE_PATH DATADIR"/"CONFIG_FILE_NAME
//#define CONFIG_FILE_PATH_HOME HOME_DIR"/"PROGRAM_DIR_NAME"/"CONFIG_FILE_NAME
//#define HOME_PATH "./"
//#define HOME_PROGRAM_PATH "./"
#//define HOME_PROGRAM_DB_PATH "./"

//#define TABLE_PROFILES "profiles"
//#define TABLE_GROUPS "profiles"


#endif /* __DB_GENERAL_H__ */
